/* Project: AVR-ASP UART console
 * Author: Andreas Butti
 * Creation Date: 2011-12-23
 * Tabsize: 4
 * Copyright: (c) 2011 Andreas Butti
 * License: GNU GPL v2
 */

#ifndef __ASPCMD_H__
#define __ASPCMD_H__

#include <usb.h>    /* this is libusb, see http://libusb.sourceforge.net/ */


/* USB identifiers */
#define	USBDEV_SHARED_VENDOR         0x16C0  /* VOTI */
#define	USBDEV_SHARED_PRODUCT        0x05DC  /* Obdev's free shared PID */

#define USBASP_FUNC_UART_CONFIGURE   17
#define USBASP_FUNC_UART_WRITEBLOCK  18
#define USBASP_FUNC_UART_READBLOCK   19
#define USBASP_FUNC_UART_AVAILABLE   20


#define USB_ERROR_NOTFOUND            1
#define USB_ERROR_ACCESS              2
#define USB_ERROR_IO                  3

/**
 * Opens the USB Device
 * close the device with: usb_close(handle);
 *
 * @return 0 or USB_ERROR_NOTFOUND, USB_ERROR_ACCESS, USB_ERROR_IO on error
 */
int usbasp_OpenDevice(usb_dev_handle **handle);

/**
 * Sets the baudrate of the UART
 *
 * @param baud, default 9600, maximum working @12MHz is 57600, but may not at full load
 */
int usbasp_SetBaud(usb_dev_handle *handle, unsigned int baud);

/**
 * Sends data to the UART, return bytes sended or < 0 on error
 */
int usbasp_SendSerial(usb_dev_handle *handle, char *buffer, int len);

/**
 * Returns the amount of bytes ready for reciving
 *
 * return the amount, or < 0 on error.
 */
int usbasp_GetSerialAvailable(usb_dev_handle *handle);

/**
 * Returns the amount of bytes read
 *
 * return the amount, or < 0 on error.
 */
int usbasp_GetSerial(usb_dev_handle *handle, char *buffer, int len);


#endif /* __ASPCMD_H__ */
